==> knative-model-6.7.1-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SubscriptionStatusPhysicalSubscriptionBuilder extends SubscriptionStatusPhysicalSubscriptionFluentImpl<SubscriptionStatusPhysicalSubscriptionBuilder> implements VisitableBuilder<SubscriptionStatusPhysicalSubscription,SubscriptionStatusPhysicalSubscriptionBuilder>{
  public SubscriptionStatusPhysicalSubscriptionBuilder() {
    this(false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(Boolean validationEnabled) {
    this(new SubscriptionStatusPhysicalSubscription(), validationEnabled);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SubscriptionStatusPhysicalSubscription(), validationEnabled);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance) {
    this(fluent, instance, false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      fluent.withReplyUri(instance.getReplyUri());
      fluent.withSubscriberUri(instance.getSubscriberUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance) {
    this(instance,false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      this.withReplyUri(instance.getReplyUri());
      this.withSubscriberUri(instance.getSubscriberUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  SubscriptionStatusPhysicalSubscriptionFluent<?> fluent;
  Boolean validationEnabled;
  public SubscriptionStatusPhysicalSubscription build() {
    SubscriptionStatusPhysicalSubscription buildable = new SubscriptionStatusPhysicalSubscription(fluent.getDeadLetterSinkUri(),fluent.getReplyUri(),fluent.getSubscriberUri());
    return buildable;
  }
  
}

==> knative-model-6.8.1-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SubscriptionStatusPhysicalSubscriptionBuilder extends SubscriptionStatusPhysicalSubscriptionFluent<SubscriptionStatusPhysicalSubscriptionBuilder> implements VisitableBuilder<SubscriptionStatusPhysicalSubscription,SubscriptionStatusPhysicalSubscriptionBuilder>{
  public SubscriptionStatusPhysicalSubscriptionBuilder() {
    this(false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(Boolean validationEnabled) {
    this(new SubscriptionStatusPhysicalSubscription(), validationEnabled);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SubscriptionStatusPhysicalSubscription(), validationEnabled);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance) {
    this(fluent, instance, false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SubscriptionStatusPhysicalSubscription());

    if (instance != null) {
      fluent.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      fluent.withReplyUri(instance.getReplyUri());
      fluent.withSubscriberUri(instance.getSubscriberUri());
      fluent.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      fluent.withReplyUri(instance.getReplyUri());
      fluent.withSubscriberUri(instance.getSubscriberUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance) {
    this(instance,false);
  }
  public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SubscriptionStatusPhysicalSubscription());

    if (instance != null) {
      this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      this.withReplyUri(instance.getReplyUri());
      this.withSubscriberUri(instance.getSubscriberUri());
      this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      this.withReplyUri(instance.getReplyUri());
      this.withSubscriberUri(instance.getSubscriberUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  SubscriptionStatusPhysicalSubscriptionFluent<?> fluent;
  Boolean validationEnabled;
  public SubscriptionStatusPhysicalSubscription build() {
    SubscriptionStatusPhysicalSubscription buildable = new SubscriptionStatusPhysicalSubscription(fluent.getDeadLetterSinkUri(),fluent.getReplyUri(),fluent.getSubscriberUri());
    return buildable;
  }
  
}
